"""Clippy parser package."""

from lintro.parsers.clippy.clippy_issue import ClippyIssue
from lintro.parsers.clippy.clippy_parser import parse_clippy_output

__all__ = ["ClippyIssue", "parse_clippy_output"]
